﻿-- Daily Global Check
-- by Jadya
-- EU-Well of Eternity

local addonName, addonTable = ...

local ldb = LibStub:GetLibrary("LibDataBroker-1.1")
local ldbicon = ldb and LibStub("LibDBIcon-1.0", true)
addonTable.ldbicon = ldbicon

local L = addonTable.L -- localization

local addontitle = "|cff00AAFFDaily Global Check|r"
local addontitle_short = "|cff00AAFFDGC|r"
local dgcicon = "Interface\\icons\\INV_Sigil_Freya"

local version = 1002

function DailyGlobalCheck:GetVersion()
 return version
end

local mapiconSizeL = 21 -- current map icons
local mapiconSizeS = 13 -- adjacent map icons

-- saved variables
DailyGlobalCheck_Options = {}
DGC_CustomLists = {}
DailyGlobalCheck_CharData = {}
DailyGlobalCheck_PluginData = {}

-- ext
DailyGlobalCheck.CharFunctions = {}
local chars = DailyGlobalCheck.CharFunctions
DailyGlobalCheck.OptFunctions = {}
local options = DailyGlobalCheck.OptFunctions
DailyGlobalCheck.PagesFunctions = {}
local pages = DailyGlobalCheck.PagesFunctions
DailyGlobalCheck.Constructors = {}
local constructors = DailyGlobalCheck.Constructors

local charData = DailyGlobalCheck_CharData
local pName = GetUnitName("player")
local pRealm = GetRealmName()
addonTable.pID = pName.."-"..pRealm
local pID = addonTable.pID
DailyGlobalCheck.selectedpID = pID
---

local DGCMenuFrame, SelectedList
local DGCTTmenu = {}
local DGCMMmenu = {}
local questsorder, questsdata
local build_mode = false
if addonTable.Plugins == nil then addonTable.Plugins = {} end
local pluginbtnsize = 25

function DailyGlobalCheck:GetActiveList()
 return SelectedList
end

-- string colors
local LIGHT_RED    = "|cffFF2020"
local LIGHT_GREEN  = "|cff20FF20"
local LIGHT_BLUE   = "|cff11DDFF"
local LIGHT_YELLOW = "|cffFFFFAA"
local ZONE_BLUE    = "|cff00aacc"
local GRAY         = "|cffAAAAAA"
local NAME_COLOR   = "|cffffffcc"
local COORD_COLOR  = "|cffDDDDDD"
local GOLD         = "|cffffcc00"
local WHITE        = "|cffffffff"
local LIST_COLOR   = "|cff00DD11"
local function AddColor(str,color)
 if not str then return "|cffFF0000<Error>|r" end
 return color..str.."|r"
end

local CustomList = 
   { ["Title"] = L["customlist"],
     ["Icon"]  = dgcicon,
     ["Data"]  = {},
     ["Order"] = {[1] = {{L["customlist"]}}, [2] = {{L["customlist"]}}, [3] = {{L["customlist"]}}}
   }

local quest_missing = AddColor(string.format(ITEM_MISSING,BATTLE_PET_SOURCE_2),LIGHT_RED)
-- buttons' textures
local arrowl = "Interface\\icons\\misc_arrowleft"
local arrowr = "Interface\\icons\\misc_arrowright"
local tx_build = "Interface\\icons\\INV_Hammer_20"
local tx_qmark = "Interface\\icons\\INV_Misc_QuestionMark"
local tx_aboutbtn     = "Interface\\icons\\Icon_PetFamily_Beast"
local tx_optionsbtn = "Interface\\icons\\Icon_PetFamily_Mechanical"
local tx_questtype = "Interface\\icons\\Achievement_Quests_Completed_06"
local tx_pref = "Interface\\icons\\INV_Fabric_Soulcloth"
local tx_zone = "Interface\\icons\\inv_misc_dmc_destructiondeck"
local tx_suff = "Interface\\icons\\INV_Fabric_Soulcloth_Bolt"
local tx_coords = "Interface\\icons\\INV_Misc_Map_01"
local tx_worldmap  = "Interface\\icons\\Ability_Hunter_Crossfire"
local tx_minimap   = "Interface\\icons\\INV_Misc_Map03"

--local tx_charlist = "Interface\\icons\\Ability_Garrosh_Touch_Of_Yshaarj"
local tx_charlist = "Interface\\icons\\Ability_Ambush"

-- constants
local ZONE = 1
local NAME = 2
local PREF = 3
local SUFF = 4
local MAPDATA = 5
local MAPDEFAULT = 6
local QUESTTYPE = 7 -- nil == daily
local MAPICON = 8 -- nil == daily global check icon
local SHOWFUNC = 9

-- build_frame menus
local addName, addID, addCategory
local function addtolist(index)

 local questID
 local questName
 local pref
 local suff
 local questCategory

 if addID then
  questID = addID
  questName = addName
  pref = ""
  suff = ""
  questCategory = addCategory
 else
  if not DailyGlobalCheck_mainframe then return end
  local f = DailyGlobalCheck_mainframe.build_frame
  if not f then return end 
  
  questID = f.edtqID:GetText()
  questName = f.edtqName:GetText()
  pref = f.edtpref:GetText()
  suff = f.edtsuff:GetText()
  questCategory = ""

  f.edtqID:SetText("")
  f.edtqName:SetText("")
  f.edtpref:SetText("")
  f.edtsuff:SetText("")
 end
 
 if questID == "" or questName == "" then
  print(L["bf_err1"])
  return
 end
 
 if CustomList["Data"][tonumber(questID)] then
  print(L["bf_err2"])
  return  
 end
 
 CustomList["Data"][tonumber(questID)] = {"",questName,pref,suff}
 
 if questCategory == "" then
  table.insert(CustomList["Order"][index][1], tonumber(questID))
 else
  local i = 1
  local inserted = false
  while CustomList["Order"][index][i] do
   if CustomList["Order"][index][i][1] == questCategory then
    table.insert(CustomList["Order"][index][i], tonumber(questID))
    inserted = true
   end
   i = i + 1
  end
  if not inserted then
   CustomList["Order"][index][i] = {questCategory}
   table.insert(CustomList["Order"][index][i], tonumber(questID))
  end
 end
 
 print("|cff11DDFFDaily Global Check|r - "..questName.." "..L["added"])
 DailyGlobalCheck:SetFramesData(CustomList["Data"], CustomList["Order"], CustomList["Title"])
 addonTable.refresh(CustomList)
end

--
local addmenu = {{text = AddColor(L["questwindow"],GOLD),notCheckable = 1, isTitle = true},
                 {text = string.format(PAGE_NUMBER, 1),notCheckable = 1, func = function() addtolist(1) end},
                 {text = string.format(PAGE_NUMBER, 2),notCheckable = 1, func = function() addtolist(2) end},
                 {text = string.format(PAGE_NUMBER, 3),notCheckable = 1, func = function() addtolist(3) end}}
local remmenu = {}
--

local opt_framespeed = 20  -- frames animation speed
local centerbuttons_spacing = 80

-- buttons utils
local starttime = 0
local lastobj
local function StartTimedGlow(obj, t)

 local function turnoff(f)
  f:SetScript("OnUpdate", nil)
  ActionButton_HideOverlayGlow(f)
 end

 if lastobj then 
  turnoff(lastobj)
  lastobj = nil
 end
 
 if not obj then return end

 local starttime = GetTime()
 ActionButton_ShowOverlayGlow(obj)
 obj:SetScript("OnUpdate", function(self) 
  local currtime = GetTime()
  if currtime > starttime + t then
   turnoff(self)
  end
 end)
 lastobj = obj
end

local function buildframecheck()
 if SelectedList == CustomList then
  DailyGlobalCheck_mainframe.buildbtn:Show()
  if build_mode then
   DailyGlobalCheck_mainframe.build_frame:Show()
  else
   DailyGlobalCheck_mainframe.build_frame:Hide()
  end
 else
  DailyGlobalCheck_mainframe.build_frame:Hide()
  DailyGlobalCheck_mainframe.buildbtn:Hide()
 end
end
-------------
local template = {[ZONE] = "", [NAME] = L["namemissing"], [PREF] = "", [SUFF] = "", [QUESTTYPE] = "D"}
local function get(tab, i)
 return tab[i] or template[i]
end
------------------------------------------------------------------------------
local function GetCoord(questID)
 local v = questsdata[questID][MAPDATA]
 local default = questsdata[questID][MAPDEFAULT]
 return v and AddColor(v[default][1]..","..v[default][2], COORD_COLOR) or ""
end
------------------------------------------------------------------------------
local function isquestcompleted(questID, mainCharOnly, notSelectedPlugin)

 local list = notSelectedPlugin or SelectedList

 if not mainCharOnly and DailyGlobalCheck.selectedpID ~= pID and list.MultiCharsEnabled then
  return chars:isquestcompleted(questID, DailyGlobalCheck.selectedpID)
 end

 if list["Overrides"] and list["Overrides"]["isquestcompleted"] then
  return list["Overrides"]["isquestcompleted"](questID)
 else
  return IsQuestFlaggedCompleted(questID)
 end
end
addonTable.isquestcompleted = isquestcompleted
------------------------------------------------------------------------------
local function isshown(questID, list)
 local qData = list and list["Data"] or questsdata
 -- there isn't a show function
 if not qData[questID] then return false end
  -- fire the show func
 return not qData[questID][SHOWFUNC] or qData[questID][SHOWFUNC]()
end

local function SetAddonTitle()
 local f = DailyGlobalCheck_mainframe
 
 if not f then return end

 local plugintitle = SelectedList and AddColor(SelectedList["Title"],LIST_COLOR) or ""
 if SelectedList then
  local suff = pID ~= DailyGlobalCheck.selectedpID and AddColor(L["opt_characters_short"], LIGHT_BLUE) or ""
  local title = SelectedList.MultiCharsEnabled and DailyGlobalCheck.selectedpID..suff or ""
  f.title:SetText(title)
  -- pages
  f.page:SetText(pages:GetString(SelectedList))
 end
 f.Ptitle:SetText(plugintitle)
end

local function GenerateLine(questID)
    local s1 = "";
    if not questsdata[questID] then return L["questdatamissing"] end

    -- quest type
    if DailyGlobalCheck_Options["show_questtype"] then
     s1 = s1..AddColor("["..get(questsdata[questID], QUESTTYPE).."]",LIGHT_BLUE) 
    end
    -- prefix
    if DailyGlobalCheck_Options["show_prefix"] and questsdata[questID][PREF] then
     s1 = s1..get(questsdata[questID], PREF)
    end
    -- zone name
    if DailyGlobalCheck_Options["show_zone"] and questsdata[questID][ZONE] then
     s1 = s1..AddColor(questsdata[questID][ZONE],GRAY)
    end
    -- quest name
    s1 = s1.." "..AddColor(get(questsdata[questID], NAME),NAME_COLOR)
    -- suffix
    if DailyGlobalCheck_Options["show_suffix"] and questsdata[questID][SUFF] then
     s1 = s1..get(questsdata[questID], SUFF).." "
    end
    -- coordinates
    if DailyGlobalCheck_Options["show_coordinates"] then
     s1 = s1.." "..AddColor(GetCoord(questID),COORD_COLOR)
    end
	
    return s1
end
---------------------------- TomTom Menu Frame -------------------------------------
local function setTomTomWaypoint(...)
 TomTom:AddMFWaypoint(...)
 local t = select(5, ...)
 print(L["s_tomtomset"].." ("..AddColor(t.title, LIGHT_BLUE)..")")
end

local function GenerateTomTomMenu()
 if not TomTom or not DGCMenuFrame then return end

  local function CreateSubMenu(q)
   local submenu = {}
   table.foreach(q, function(index,questID)
    if questsdata[questID] and index > 1 and isshown(questID) then
    table.insert(submenu, { text = get(questsdata[questID], NAME).." - "..AddColor(get(questsdata[questID], ZONE),GRAY).." "..GetCoord(questID),
                            disabled = isquestcompleted(questID) or not questsdata[questID][MAPDATA],
                            notCheckable = 1,
                            keepShownOnClick = true,
                            func = function(self)
                               if questsdata[questID] and questsdata[questID][MAPDATA] then
                                 setTomTomWaypoint(questsdata[questID][MAPDEFAULT], nil,
                                            questsdata[questID][MAPDATA][questsdata[questID][MAPDEFAULT]][1] / 100,
                                            questsdata[questID][MAPDATA][questsdata[questID][MAPDEFAULT]][2] / 100,
                                          { title = get(questsdata[questID], NAME)})
                               end
                              end
                              })
     end
    end)
    return submenu
   end

  wipe(DGCTTmenu)
  table.insert(DGCTTmenu, {text = AddColor("- TomTom Waypoints -",GOLD),notCheckable = 1, isTitle = true})
  table.insert(DGCTTmenu, {text = AddColor("Click either a single quest or a group",LIGHT_BLUE),notCheckable = 1, isTitle = true})
  table.insert(DGCTTmenu, {text = AddColor("to set TomTom waypoints",LIGHT_BLUE),notCheckable = 1, isTitle = true})
  table.insert(DGCTTmenu, {text = "",notCheckable = 1, isTitle = true})

  table.foreach(questsorder, function(k,tab)
   local pref = "|T"..SelectedList["Icon"]..":12|t"
   table.foreach(tab, function(header,quests)
    if table.getn(quests) > 1 then
    table.insert(DGCTTmenu, { text = quests[1] ~= "" and pref..quests[1] or pref..L["notitle"],
                              keepShownOnClick = true,
                              notCheckable = 1,
                       func = function(self)
                               table.foreach(quests, function(index, questID)
							    if index > 1 then
                                  if questsdata[questID] and questsdata[questID][MAPDATA] and not isquestcompleted(questID) and isshown(questID) then
                                   TomTom:AddMFWaypoint(questsdata[questID][MAPDEFAULT], nil,
                                              questsdata[questID][MAPDATA][questsdata[questID][MAPDEFAULT]][1] / 100,
                                              questsdata[questID][MAPDATA][questsdata[questID][MAPDEFAULT]][2] / 100,
                                            { title = get(questsdata[questID], NAME) } )
                                   print(L["s_tomtomset"].." ("..AddColor(get(questsdata[questID], NAME),LIGHT_BLUE)..")")
                                 end
								end
                               end)
                              end,
                       hasArrow = true,
		               menuList = CreateSubMenu(quests)})
	end
   end)
  end)
  table.insert(DGCTTmenu, {text = "", isTitle = true, notCheckable = 1})
  table.insert(DGCTTmenu, {text = CLOSE, notCheckable = 1})
end
------------------------------------------ Draw Frame --------------------------------------------------------
local function DrawFrame(obj, istooltip)

 local tmpleft  = ""
 local tmpright = ""
 
 local index = pages:Curr()

  local function adddoubleline(left,right)
  if istooltip then obj:AddDoubleLine(left,right) return end

  tmpleft  = tmpleft.."\n"..left
  tmpright = tmpright.."\n"..right
 end

 if not SelectedList then -- this should never happen since Custom List is always available
  if table.getn(addonTable.Plugins) == 0 and CustomList == nil then
   adddoubleline(AddColor("No lists available",LIGHT_RED)," ")
   adddoubleline(" "," ")
   adddoubleline(AddColor("Check out on curse:",LIGHT_RED)," ")
   adddoubleline(AddColor("Daily Global Check_World Bosses",WHITE)," ")
   adddoubleline(AddColor("Daily Global Check_Pet Tamers",WHITE)," ")
   adddoubleline(AddColor("Daily Global Check_Isle of Thunder",WHITE)," ")
   adddoubleline(AddColor("Daily Global Check_Timeless Isle",WHITE)," ")
   adddoubleline(AddColor("Daily Global Check_GarrisonMissions",WHITE)," ")
   adddoubleline(AddColor("...and more to come!",WHITE)," ")
  else
   adddoubleline(AddColor(L["nolist"],LIGHT_RED)," ")
  end
 else
 
  if SelectedList["OnShow"] then SelectedList["OnShow"]() end
  options:OnDraw()
  
  if not questsorder[index] then return end

  local s1,s2
  table.foreach(questsorder[index], function(k,v)
   if v[1] ~= "" then
    adddoubleline(AddColor(v[1],GOLD)," ")
   end
   table.foreach(v,function(i,questID)
           if i > 1 then
		     if isshown(questID) then
			  local completed, cstring = isquestcompleted(questID, istooltip)
			  if not DailyGlobalCheck_Options["hide_completed"] or not completed then
			   if cstring == nil then cstring = completed and COMPLETE or INCOMPLETE end
               s2 = AddColor(cstring,completed and LIGHT_GREEN or LIGHT_RED)
               s1 = GenerateLine(questID)
               adddoubleline(s1,s2)
			  end
		 	end
	      end
    end)
    adddoubleline(" "," ")
   end)
  end
 if not istooltip then
   DailyGlobalCheck_mainframe.dgcicon:SetTexture(SelectedList["Icon"] or dgcicon)

 -- create some space for the buttons
  local plus = pluginbtnsize * 5
  obj.leftfont:SetText(tmpleft)
  obj.rightfont:SetText(tmpright)
  obj:SetSize(math.max(300, obj.leftfont:GetWidth() + obj.rightfont:GetWidth() + 30),obj.leftfont:GetHeight() + plus)
  local fnt = DailyGlobalCheck_mainframe.Ptitle
  local w = fnt:GetWidth()
  fnt:SetPoint("TOPLEFT", DailyGlobalCheck_mainframe, "TOPLEFT", (DailyGlobalCheck_mainframe:GetWidth() - 70) / 2 - w / 2, -15)
 else
  obj:AddLine(pages:GetString(SelectedList))
  obj:AddLine(AddColor(L["lclicktoopen"],LIGHT_BLUE))
  obj:AddLine(AddColor(L["rclicktoopen"],LIGHT_BLUE))
  obj:Show()
 end
end
---------------------------- Chat Output ---------------------------------------------
local function ChatOutput()
 if not questsorder[1] then return end

 local s1,s2
 table.foreach(questsorder[1], function(k,v)
 if v[1] ~= "" then
  print(AddColor(v[1],GOLD))
 end
 table.foreach(v,function(i,questID)
        if i > 1 then
	    if isshown(questID) then
			local completed, cstring = isquestcompleted(questID)
			if cstring == nil then cstring = completed and COMPLETE or INCOMPLETE end
            s2 = AddColor(cstring,completed and LIGHT_GREEN or LIGHT_RED)
            s1 = GenerateLine(questID)
            print(s1.." "..s2)
		end
     end
  end)
 end)
end

---------------------------- set frames data -----------------------------------------
function DailyGlobalCheck:SetFramesData(data, order, plugintitle)
 if not data or not order or (plugintitle and SelectedList and plugintitle ~= SelectedList["Title"]) then return false end

 questsdata = data
 questsorder = order

 --wipe(questsdata)
 --table.foreach(data, function(k,v) questsdata[k] = v end)
 --wipe(questsorder)
 --table.foreach(order, function(k,v) questsorder[k] = v end)
 
 if DailyGlobalCheck_mainframe then
  DailyGlobalCheck_mainframe.UpdateArrows()
 end
end

local function OpenList(v)
 local list

 local function lflist(_,t)
  if t["Title"] == v then list = t end
 end

 if type(v) == "string" then
  table.foreach(addonTable.Plugins, lflist)
  if not list then list = CustomList end
 else 
  list = v
 end

 if not list then return end
 SelectedList = list
 DailyGlobalCheck_Options["last_selected"] = list["Title"]
 DailyGlobalCheck:SetFramesData(list["Data"], list["Order"])
 GenerateTomTomMenu()
 addonTable.forcemapupdate()
 if DGCMenuFrame then DGCMenuFrame:Hide() end
 if DailyGlobalCheck_mainframe then
  buildframecheck()
  SetAddonTitle()
  local btns = DailyGlobalCheck_mainframe.listbuttons
  if btns[SelectedList["Title"]] then
   table.foreach(btns, function(k,v) v:Deselect() end)
   btns[SelectedList["Title"]]:Select()
   StartTimedGlow(btns[SelectedList["Title"]], 2)
  end
  DrawFrame(DailyGlobalCheck_mainframe, false)
 end
end
---------------------------------------------------------------------
local function GenerateMinimapMenu()
 if not DGCMMmenu then return end

  local function CreateListsMenu()
   local submenu = {}
   table.insert(submenu, {text = L["customlist"], notCheckable = 1, keepShownOnClick = true, func = function() OpenList(CustomList) end})
   table.foreach(addonTable.Plugins, function(k,v)
    table.insert(submenu, { text = v["Title"],
                            --disabled = false,
                            notCheckable = 1,
                            keepShownOnClick = true,
                            func = function()
                               OpenList(v)
                              end
                              })
    end)
    return submenu
   end

  DGCMMmenu = {}
  table.insert(DGCMMmenu, {text = AddColor(L["availablelists"],GOLD),notCheckable = 1, hasArrow = true, menuList = CreateListsMenu()})
  
  if TomTom and DGCTTmenu then
   table.insert(DGCMMmenu, {text = AddColor("TomTom",GOLD),notCheckable = 1, hasArrow = true, menuList = DGCTTmenu})
  end
  
  table.insert(DGCMMmenu, {text = "", isTitle = true, notCheckable = 1})

  table.insert(DGCMMmenu, {text = L["prevpage"], notCheckable = 1, func = function() 
   if pages:Move(SelectedList, -1) and DGC_Mainframe then
    DGC_Mainframe.ChangeAnchor("BOTTOMLEFT")
    addonTable.refresh(SelectedList)
   end
  end})
  
  table.insert(DGCMMmenu, {text = L["nextpage"], notCheckable = 1, func = function() 
   if pages:Move(SelectedList, 1) and DGC_Mainframe then
    DGC_Mainframe.ChangeAnchor("BOTTOMLEFT")
    addonTable.refresh(SelectedList)
   end
  end})
--  table.insert(DGCTTmenu, {text = "",notCheckable = 1, isTitle = true})
  table.insert(DGCMMmenu, {text = "", isTitle = true, notCheckable = 1})
  table.insert(DGCMMmenu, {text = CLOSE, notCheckable = 1})
  EasyMenu(DGCMMmenu, DGCMenuFrame, "cursor", -100 , 0, "MENU")
end

local function GenerateRemoveButtonMenu()

 local function CreateSubMenu(q, page, header)
   local submenu = {}
   table.foreach(q, function(index,questID)
    if questsdata[questID] and index > 1 and isshown(questID) then
    table.insert(submenu, { text = get(questsdata[questID], NAME),
                            notCheckable = 1,
                            func = function(self)
							    if CustomList["Data"][questID] then
                                 print("|cff11DDFFDaily Global Check|r - "..get(CustomList["Data"][questID], NAME).." "..L["deleted"])
								 local i = 1
                                 while q[i] do
                                  if questID == q[i] then
                                   table.remove(q, i)
								  else
								   i = i + 1
								  end
								 end
								 
                                 if table.getn(q) <= 1 then
                                  page[header] = nil
 								 end
								 
								 CustomList["Data"][questID] = nil
								 addonTable.refresh(CustomList)
								end
                              end
                              })
     end
    end)
    return submenu
   end

  wipe(remmenu)
  table.insert(remmenu, {text = L["remmenuheader"], isTitle = true, notCheckable = 1})
  table.insert(remmenu, {text = "",notCheckable = 1, isTitle = true})

  for k,page in pairs(CustomList["Order"]) do
   local pref = "|T"..SelectedList["Icon"]..":12|t"
   for header,quests in pairs(page) do
    if table.getn(quests) > 1 then
    table.insert(remmenu, { text = quests[1] ~= "" and pref..quests[1] or pref..L["notitle"],
                            keepShownOnClick = true,
                            notCheckable = 1,
                            hasArrow = true,
		                    menuList = CreateSubMenu(quests, page, header)})
	end
   end
  end
  table.insert(remmenu, {text = "", isTitle = true, notCheckable = 1})
  table.insert(remmenu, {text = CLOSE, notCheckable = 1})
end


local function CheckFramesAnimation(frame)
 if (frame) and (frame:IsVisible()) and (frame.maxwidth ~= nil) and (frame.width ~= nil) and (frame.opening ~= nil) then
  if frame.opening then
   if frame.width < frame.maxwidth then
    frame.width = frame.width + opt_framespeed
    frame:SetHeight(frame.width)
   elseif (not frame.leftfont:IsVisible()) then
    frame.leftfont:Show()
    frame.rightfont:Show()
   end
  else -- closing
   if frame.width > opt_framespeed then
    frame.width = frame.width - opt_framespeed
	 -- about frame hack
    frame:SetHeight(frame.width)
    if (frame.leftfont:IsVisible()) then
     frame.leftfont:Hide()
     frame.rightfont:Hide()
    end
   else
    frame:Hide()
   end
  end
 end
end

local function CreateAboutFrame()

 local btn, f
 f = CreateFrame("Frame")
 f:SetParent(DailyGlobalCheck_mainframe)
 constructors:SetupFrame(f)
 f.width = 1
 f.maxwidth = 180
 f.leftfont:Hide()
 f.rightfont:Hide()
 f:SetFrameStrata("DIALOG")
 f:SetClampedToScreen(true)
 f:ClearAllPoints()
 f:SetPoint("TOPLEFT", DailyGlobalCheck_mainframe, "BOTTOMLEFT")
 f:SetPoint("TOPRIGHT", DailyGlobalCheck_mainframe, "BOTTOMRIGHT")
 
 btn = CreateFrame("FRAME", nil, DailyGlobalCheck_mainframe)
 btn.tex = btn:CreateTexture()
 btn:SetPoint("BOTTOM", DailyGlobalCheck_mainframe, "BOTTOM",centerbuttons_spacing,10)
 btn:SetSize(25,25)
 btn.tex:SetAllPoints()
 btn.tex:SetTexture(tx_aboutbtn)
 btn.enabled = true
 
 f.leftfont:SetText(AddColor(" Daily Global Check ",GOLD).."\n"..
                                         AddColor(" by\n",GRAY)..
                                         AddColor(" Jadya",LIGHT_BLUE)..
                                         AddColor(" EU-Well of Eternity\n\n",GRAY)..
										 AddColor(" Plugins available on Curse:\n",LIGHT_GREEN)..
                                         AddColor(" Daily Global Check_World Bosses\n"..
                                         " Daily Global Check_Isle of Thunder\n"..
                                         " Daily Global Check_Timeless Isle\n"..
                                         " Daily Global Check_Pet Tamers\n"..
										 " Daily Global Check_GarrisonMissions\n"..
										 " Daily Global Check_GarrisonWorkOrders\n"..
										 " Daily Global Check_WoD Rare Mobs\n"..
										 " Daily Global Check_WoD Treasure Chests\n",GRAY)
										 )
 f.rightfont:SetText("|T"..dgcicon..":24|t\n")

 -- frame's opening/closing animation
 f:SetScript("OnUpdate", function(self)
   CheckFramesAnimation(f)
  end)

  btn:SetScript("OnEnter", function(self)
   if btn.enabled then
    f.opening = true
    f:SetHeight(f.width)
    f:Show()
   end
 end)

  btn:SetScript("OnLeave", function(self)
    f.opening = false 
  end)
 btn:Show()
 
 if f.opening then f:Show() else f:Hide() end
 DailyGlobalCheck_mainframe.fabout = f
 DailyGlobalCheck_mainframe.btnabout = btn
end --CreateNewFrameButton

-- Initialize Mainframe
local function DGCInit(arg)
 local f = DailyGlobalCheck_mainframe

 if arg == "print" then
  print(AddColor("Daily Global Check",LIGHT_BLUE))
  ChatOutput()
  print(AddColor("---",LIGHT_BLUE))
  return
 elseif arg == "config" then
  DailyGlobalCheck.OptionsPanel:Show()
  return
 end
 
 if f then
  if f:IsVisible() then
   f:Hide()
   if DGCMenuFrame then DGCMenuFrame:Hide() end
   collectgarbage()
  else
   DrawFrame(f, false)
   if SelectedList and SelectedList["Title"] and f.listbuttons[SelectedList["Title"]] then
    StartTimedGlow(f.listbuttons[SelectedList["Title"]], 3)
   end
   f:Show()
  end
 else
  DailyGlobalCheck_mainframe = CreateFrame("Frame", "DGC_Mainframe", UIParent)
  f = DailyGlobalCheck_mainframe
  f:SetPoint("CENTER")
  f:SetMovable(true)
  f:EnableMouse(true)
  f:RegisterForDrag("LeftButton")
  
  local function changeanchor(anchor)
  
   local x,y = f:GetLeft(), f:GetTop()
   f:ClearAllPoints()
   y = -GetScreenHeight() + y
   
   if anchor == "TOPLEFT" then
    f:SetPoint(anchor, UIParent, "TOPLEFT", x, y)
   elseif anchor == "TOPRIGHT" then
    f:SetPoint(anchor, UIParent, "TOPLEFT", x + f:GetWidth(), y)
   elseif anchor == "BOTTOMLEFT" then
    f:SetPoint(anchor, UIParent, "TOPLEFT", x, y - f:GetHeight())
	elseif anchor == "BOTTOMRIGHT" then
    f:SetPoint(anchor, UIParent, "TOPLEFT", x + f:GetWidth(), y - f:GetHeight())
   end
  end

  f.ChangeAnchor = changeanchor
  
  f:SetScript("OnDragStart", function(self) 
   f:StartMoving()
  end)
  f:SetScript("OnDragStop",  function(self) 
   f:StopMovingOrSizing()
  end)
  f.buttons  = {}
  f.frames = {}
  constructors:SetupFrame(f)
  
  f.Lbtn = constructors:CreateStaticBtn(f, arrowl, {"BOTTOMLEFT", f, "BOTTOMLEFT",10,10}, {L["prevpage"]})
  f.Rbtn = constructors:CreateStaticBtn(f, arrowr, {"BOTTOMRIGHT", f, "BOTTOMRIGHT",-10,10}, {L["nextpage"]})

  f.UpdateArrows = function()
   if pages:Curr() == 1 then
    f.Lbtn.tex:SetVertexColor(0.4,0.4,0.4,1)
   else
    f.Lbtn.tex:SetVertexColor(1,1,1,1)
   end
   
   if pages:Curr() == pages:Max() then
    f.Rbtn.tex:SetVertexColor(0.4,0.4,0.4,1)
   else
    f.Rbtn.tex:SetVertexColor(1,1,1,1)
   end
  end
  
  f.Lbtn:SetScript("OnMouseUp", function(self)
   if pages:Move(SelectedList, -1) then
    f.ChangeAnchor("BOTTOMLEFT")
    addonTable.refresh(SelectedList)
   end
  end)

  f.Rbtn:SetScript("OnMouseUp", function(self)
   if pages:Move(SelectedList, 1) then
    f.ChangeAnchor("BOTTOMRIGHT")
    addonTable.refresh(SelectedList)
   end
  end)

  f.UpdateArrows()
   
  -- about frame
  CreateAboutFrame()

 -- options
 local optframe = options:CreateOptionsFrame(f)
 f.btnoptions = constructors:CreatePanelBtn(f, tx_optionsbtn, optframe, {"BOTTOMRIGHT",f,"BOTTOMRIGHT",-10,40},{GAMEOPTIONS_MENU})
 
 -- characters
 local charframe = chars:CreateCharactersFrame(f)
 f.btnchars = constructors:CreatePanelBtn(f, tx_charlist, charframe, {"BOTTOM",f,"BOTTOM",-centerbuttons_spacing,10},{BINDING_NAME_TOGGLECHARACTER0})

-- lists and plugins buttons
-- Mainframe Icon
 f.dgcicon = f:CreateTexture("ARTWORK")
 f.dgcicon:SetPoint("TOPRIGHT", f, "TOPRIGHT", -20, 10)
 f.dgcicon:SetTexture(dgcicon)
 f.dgcicon:SetSize(50,50)
-- Selected List Title
 f.Ptitle = f:CreateFontString()
 f.Ptitle:SetFont("Fonts\\FRIZQT__.ttf", 20, "")
 f.Ptitle:SetPoint("TOPLEFT", f, "TOPLEFT", 10, -5)
 
-- Character Name
 f.title = f:CreateFontString()
 f.title:SetFont("Fonts\\ARIALN.ttf", 12, "")
 f.title:SetPoint("TOP", f.Ptitle, "BOTTOM", 0, -5)

-- Pages
 f.page = f:CreateFontString()
 f.page:SetFont("Fonts\\ARIALN.ttf", 13, "")
 f.page:SetPoint("BOTTOM", f, "BOTTOM", 0, 40)
 
 SetAddonTitle()
-- Mainframe fonts offset
 f.leftfont:SetPoint("TOPLEFT",10,-pluginbtnsize * 2)
 f.rightfont:SetPoint("TOPRIGHT",-10,-pluginbtnsize * 2)
-- Plugin Buttons
 f.listbuttons = {}
 local counter = 0
 local function createlistbutton(_,v)
  local btn = constructors:CreateListButton(f)
  f.listbuttons[v["Title"]] = btn
  btn:SetSize(25,25)
  local l = counter % 8
  local r = math.floor(counter / 8) + 1
  btn:SetPoint("TOPLEFT", f, "TOPLEFT", 5 + l + (l * pluginbtnsize), pluginbtnsize * r + 1)  
  btn.tooltiplines = {v["Title"]}
  if v == SelectedList then
   btn:Select()
   StartTimedGlow(btn, 3)
  end
  btn:SetIcon(v["Icon"] and v["Icon"] or tx_qmark)
  btn.clickfunc = function()
                   f.ChangeAnchor("TOPLEFT")
                   OpenList(v)
                  end
  btn.position = counter
  counter = counter + 1
 end

 -- custom list button
 createlistbutton(_, CustomList)
 -- plugin buttons
 table.sort(addonTable.Plugins, function(a,b) return string.lower(a["Title"]) < string.lower(b["Title"]) end)
 table.foreach(addonTable.Plugins, createlistbutton)
 
 -------------------------------------------------------

 -- "show/hide build frame" button
 f.buildbtn = constructors:CreateListButton(f)
 f.buildbtn:SetPoint("TOPLEFT", f, "TOPLEFT", 10, -10)
 f.buildbtn:SetSize(25,25)
 f.buildbtn:SetIcon(tx_build)
 f.buildbtn.tooltiplines = {L["buildframe"]}
 f.buildbtn.clickfunc = function()
     build_mode = not build_mode
	 buildframecheck()
	 local h = f.build_frame:GetHeight()
	 if h < 170 then
	  f.build_frame:SetPoint("BOTTOMRIGHT",f,"BOTTOMLEFT", 0, -( 170 - h ))
	 end
  end
-- build frame
 -- build frame icon
 f.build_frame = CreateFrame("FRAME", nil, f)
 f.build_frame:SetPoint("TOPLEFT",f,"TOPLEFT", -150, 0)
 f.build_frame:SetPoint("BOTTOMRIGHT",f,"BOTTOMLEFT")
 f.build_frame.tex = f.build_frame:CreateTexture()
 f.build_frame.tex:SetAllPoints()
 f.build_frame.tex:SetTexture(0,0,0,1)
 -- quest ID editbox
 f.build_frame.edtqID = constructors:editboxtemplate(f.build_frame, L["b_questid"])
 f.build_frame.edtqID:SetPoint("TOPLEFT", f.build_frame, "TOPLEFT", 5, -15)
 f.build_frame.edtqID:SetScript("OnEnterPressed", function(self) f.build_frame.edtqName:SetFocus() end)
 local lasttext = ""
 f.build_frame.edtqID:SetScript("OnTextChanged", function(self)
   local text = self:GetText()
   if strfind(text, "%D") then
    self:SetText(lasttext)
   else
    lasttext = text
   end
  end)
 -- quest name editbox
 f.build_frame.edtqName = constructors:editboxtemplate(f.build_frame, L["b_questname"])
 f.build_frame.edtqName:SetPoint("TOPLEFT", f.build_frame.edtqID, "BOTTOMLEFT", 0, -15)
 f.build_frame.edtqName:SetScript("OnEnterPressed", function(self) f.build_frame.edtpref:SetFocus() end)
 -- prefix editbox
 f.build_frame.edtpref = constructors:editboxtemplate(f.build_frame, L["b_prefix"])
 f.build_frame.edtpref:SetPoint("TOPLEFT", f.build_frame.edtqName, "BOTTOMLEFT", 0, -15)
 f.build_frame.edtpref:SetScript("OnEnterPressed", function(self) f.build_frame.edtsuff:SetFocus() end)
 -- suffix editbox
 f.build_frame.edtsuff = constructors:editboxtemplate(f.build_frame, L["b_suffix"])
 f.build_frame.edtsuff:SetPoint("TOPLEFT", f.build_frame.edtpref, "BOTTOMLEFT", 0, -15)
 f.build_frame.edtsuff:SetScript("OnEnterPressed", function(self) self:ClearFocus() end)
 -- add button
 f.build_frame.addbtn = constructors:largebuttontemplate(f.build_frame, L["add"], L["add"])
 f.build_frame.addbtn:SetPoint("TOPRIGHT")
 f.build_frame.addbtn:SetBackdropColor(0,1,0,0.8)
 f.build_frame.addbtn:SetScript("OnMouseUp", function()
    addName = nil
	addID = nil
    EasyMenu(addmenu, DGCMenuFrame, "cursor", -100 , 0, "MENU")
  end)
 -- remove button
 f.build_frame.rembtn = constructors:largebuttontemplate(f.build_frame, L["rem"], L["rem"])
 f.build_frame.rembtn:SetPoint("TOPRIGHT",f.build_frame,"TOPRIGHT",0,-25)
 f.build_frame.rembtn:SetBackdropColor(1,0,0,0.8)
 f.build_frame.rembtn:SetScript("OnMouseUp", function()
    GenerateRemoveButtonMenu()
    EasyMenu(remmenu, DGCMenuFrame, "cursor", -100 , 0, "MENU")
  end)
 f.build_frame:Hide()
 -- build frame end

-- TomTom button
if TomTom then
 f.TomTombutton = constructors:largebuttontemplate(f, "TomTom", L["tomtom_button"])
 f.TomTombutton:SetPoint("BOTTOMLEFT",f,"BOTTOMLEFT",5,40)
 f.TomTombutton:SetBackdropColor(1,0,0.3,1)
 f.TomTombutton:SetScript("OnMouseUp", function()
   if DGCMenuFrame then
    if DGCMenuFrame:IsVisible() then
     DGCMenuFrame:Hide()
    end
    DGCMenuFrame:SetPoint("TOP",f.TomTombutton,"BOTTOM",0,-5)
    EasyMenu(DGCTTmenu, DGCMenuFrame, DGCMenuFrame, 0 , 0, "MENU")
   end
   end)
end
 -- close button
  f.closebtn = constructors:CreateListButton(f)
  f.closebtn:SetPoint("BOTTOM", f, "BOTTOM",0,10)
  f.closebtn:SetSize(100,25)
  f.closebtn:SetText(CLOSE)
  f.closebtn.clickfunc = function()
                        if f.frames then
                         table.foreach(f.frames,function(k,v) v:Hide() end)
                        end
                        f:Hide()
                        if DGCMenuFrame then DGCMenuFrame:Hide() end
                        collectgarbage()
                       end
  f:SetSize(300,150)
  DrawFrame(f, false)
  buildframecheck()
  f:Show()
 end
end

--- world map section
local mapID
local active_buttons = 1
DailyGlobalCheck_mapframe = CreateFrame("Frame")
DailyGlobalCheck_mapframe:SetParent(WorldMapButton)
DailyGlobalCheck_mapframe:SetAllPoints()
DailyGlobalCheck_mapframe.framespool = {}
CreateFrame("GameTooltip","DailyGlobalCheck_maptooltip", nil, "GameTooltipTemplate")
DailyGlobalCheck_maptooltip:SetFrameStrata("TOOLTIP")
DailyGlobalCheck_maptooltip:SetScale(0.8)

local function createmapbutton()
 local f = CreateFrame("FRAME")
 f:SetParent(DailyGlobalCheck_mapframe)
 f:SetPoint("CENTER",DailyGlobalCheck_mapframe,"CENTER")
 f.data = {}
 f:SetScript("OnMouseUp", function(_, mousebutton)
   if IsControlKeyDown() and mousebutton == "RightButton" then
    local qID, list = f.data[1], f.data[2]

	if not list or not qID or not list["Data"][qID] then return end
    local qData = list["Data"][qID]
	
    local x = qData[MAPDATA][qData[MAPDEFAULT]][1] / 100
	local y = qData[MAPDATA][qData[MAPDEFAULT]][2] / 100
	setTomTomWaypoint(qData[MAPDEFAULT], nil, x, y, { title = get(qData, NAME)})
   else
    WorldMapButton_OnClick(WorldMapButton, mousebutton)
   end
  end)
 
 f:SetScript("OnLeave", function()
  DailyGlobalCheck_maptooltip:Hide()
 end)
 f.tex = f:CreateTexture()
 f.tex:SetAllPoints()
 f:SetFrameStrata("HIGH")
 table.insert(DailyGlobalCheck_mapframe.framespool, f)
 return f
end


local function addMapIcons(list)

  local qData = list["Data"]
  for qID,v in pairs(qData) do
     if not isquestcompleted(qID, true, list) and qData[qID] and isshown(qID, list) then
      if qData[qID][MAPDATA] and qData[qID][MAPDATA][mapID]  then
       -- pick up an unused frame or create a new one
       local f = DailyGlobalCheck_mapframe.framespool[active_buttons] ~= nil and DailyGlobalCheck_mapframe.framespool[active_buttons] or createmapbutton()
       local x = qData[qID][MAPDATA][mapID][1]
       local y = qData[qID][MAPDATA][mapID][2]
       f:SetWidth(qData[qID][MAPDEFAULT] == mapID and mapiconSizeL or mapiconSizeS)
       f:SetHeight(qData[qID][MAPDEFAULT] == mapID and mapiconSizeL or mapiconSizeS)
       f:SetPoint("CENTER",DailyGlobalCheck_mapframe,"TOPLEFT",
         -- I simply treat coordinates as a percentage of the width/height of the map frame
              DailyGlobalCheck_mapframe:GetWidth()  * x / 100,
             -DailyGlobalCheck_mapframe:GetHeight() * y / 100)
       f.data[1] = qID
	   f.data[2] = list
	   f:SetScript("OnEnter", function()
        DailyGlobalCheck_maptooltip:SetOwner(f,"ANCHOR_BOTTOM")
        DailyGlobalCheck_maptooltip:ClearLines()
        DailyGlobalCheck_maptooltip:AddLine(addontitle)
        DailyGlobalCheck_maptooltip:AddLine(AddColor(list["Title"],LIGHT_BLUE))
        DailyGlobalCheck_maptooltip:AddLine(qData[qID][PREF].." "..qData[qID][NAME])
        DailyGlobalCheck_maptooltip:AddLine(qData[qID][SUFF])
        DailyGlobalCheck_maptooltip:Show()
       end)
       f.tex:SetTexture(qData[qID][MAPICON] or dgcicon,1)
       f:Show()
       active_buttons = active_buttons + 1
      end
     end
    end
end

local function DGCworldmapupdate()
  DailyGlobalCheck_mapframe:Hide()
  DailyGlobalCheck_maptooltip:Hide()
  if not DailyGlobalCheck_Options["show_mapicons"] or GetCurrentMapContinent() == WORLDMAP_COSMIC_ID 
     or GetNumDungeonMapLevels() ~= 0 then --or not WorldMapButton:IsVisible() then
   return
  end

  if mapID ~= GetCurrentMapAreaID() then
   for _,v in pairs(DailyGlobalCheck_mapframe.framespool) do
    v:Hide() 
   end

   active_buttons = 1
   mapID = GetCurrentMapAreaID()
   if not DailyGlobalCheck_Options["show_mapicons_all"] then
    for _,pInfo in pairs(addonTable.Plugins) do
     addMapIcons(pInfo)
    end
   else
    addMapIcons(SelectedList)
   end
  end

  if active_buttons > 1 then
   DailyGlobalCheck_mapframe:Show()
  end
end

-- resizing the map through those buttons does not fire the world_map_update event,
-- even if that changes the mapID to the player's current map, so I hook them
WorldMapFrameSizeDownButton:HookScript("OnClick", DGCworldmapupdate)
WorldMapFrameSizeUpButton:HookScript("OnClick", DGCworldmapupdate)

--- world map section end

addonTable.refresh = function(plugin)
 if not plugin or SelectedList == plugin then
  if DailyGlobalCheck_mainframe then
   SetAddonTitle()
   DailyGlobalCheck_mainframe.UpdateArrows()
   DrawFrame(DailyGlobalCheck_mainframe, false)
  end
 end
end

addonTable.forcemapupdate = function()
 mapID = -1
 DGCworldmapupdate()
end

WorldMapButton:HookScript("OnShow", addonTable.forcemapupdate)

local ldbset = false
local lastselset = false
local eventframe = CreateFrame("FRAME","DGCEventFrame")
eventframe:RegisterEvent("WORLD_MAP_UPDATE")
eventframe:RegisterEvent("PLAYER_LOGIN")

function eventframe.WORLD_MAP_UPDATE(...)
 if WorldMapFrame:IsVisible() then
  DGCworldmapupdate()
 end
end

function eventframe.PLAYER_LOGIN(...)

  if DailyGlobalCheck_Options == nil then DailyGlobalCheck_Options = {} end
  
  local O = DailyGlobalCheck_Options
  
  if O["show_questtype"]   == nil then O["show_questtype"]   = false end
  if O["show_coordinates"] == nil then O["show_coordinates"] = true end
  if O["show_zone"]        == nil then O["show_zone"]        = false end
  if O["show_prefix"]      == nil then O["show_prefix"]      = false end
  if O["show_suffix"]      == nil then O["show_suffix"]      = false end
  if O["show_mapicons"]    == nil then O["show_mapicons"]    = true end
  if O["show_mapicons_all"]== nil then O["show_mapicons_all"]= false end
  if O["show_questlogbtn"] == nil then O["show_questlogbtn"] = true end
  if O["chars_blacklist"]  == nil then O["chars_blacklist"]  = {} end
  if O["hide_completed"]   == nil then O["hide_completed"]   = false end
  
  if not DGC_CustomLists["Main"] then
   DGC_CustomLists["Main"] = CustomList
  else
   CustomList = DGC_CustomLists["Main"]
  end
  CustomList.MultiCharsEnabled = true
  
  for k,v in pairs(addonTable.Plugins) do
   if not DailyGlobalCheck_PluginData[v["Title"]] then
    DailyGlobalCheck_PluginData[v["Title"]] = {}
   end
  end

  DGCMenuFrame = CreateFrame("Frame", "DGCMenuFrame", UIParent, "UIDropDownMenuTemplate")

  -- saved selected list
  if not lastselset then
   local lastsel = O["last_selected"]
   if lastsel then
    OpenList(lastsel)
   elseif table.getn(addonTable.Plugins) > 0 then
    OpenList(addonTable.Plugins[1])
   elseif CustomList then
    OpenList(CustomList)
   end
   lastselset = true
  end
  
  ---
  
  if O["minimap_icon"] == nil then -- show minimap icon
    O["minimap_icon"] = {
        hide = false,
        minimapPos = 220,
    }
  end
  O["DGC_Version"] = version

  if ldb and not ldbset then
        local DailyGlobalCheck_broker = ldb:NewDataObject("Daily Global Check", {
	        type = "data source",
	        icon = dgcicon,
	        label = "Daily Global Check",
	        OnClick = function(self,button)
			 if button == "LeftButton" then
               DGCInit()
			 elseif button == "RightButton" then
			  GenerateMinimapMenu()
			 end
	        end,
	        OnTooltipShow = function(tooltip)
			 if SelectedList then
			  tooltip:ClearLines()
			  tooltip:AddLine(addontitle..AddColor(" ("..SelectedList["Title"]..")",LIGHT_BLUE))
		      DrawFrame(tooltip,true)
			 end
	    end,
        })
        if ldbicon then
            ldbicon:Register("DailyGlobalCheck_broker", DailyGlobalCheck_broker, O["minimap_icon"])
        end
   ldbset = true
 end
end

eventframe:SetScript("OnEvent", function(self, event, ...) eventframe[event](...) end)

-- "Add quest to Custom List" menubutton in the QuestMap frame
-- (thanks leniver for the categories part)
local function hookToggleDropDownMenu(level, value, dropDownFrame, anchorName, xOffset, yOffset, menuList, button, autoHideDelay)
 if dropDownFrame ~= QuestMapQuestOptionsDropDown or not DailyGlobalCheck_Options["show_questlogbtn"] then
  return
 end 

 local questLogIndex = GetQuestLogIndexByID(dropDownFrame.questID)
 local questTitle, questLevel, _, _, _, _, _, isDaily = GetQuestLogTitle(questLogIndex)
 local info = UIDropDownMenu_CreateInfo()
 local questCategory = ""
 
 local i = 1
 while GetQuestLogTitle(i) do
  local questTitleForCategory, _, _, isHeader, _, _, _, questIDForCategory  = GetQuestLogTitle(i)
  if isHeader then
   questCategory = questTitleForCategory
  elseif  questIDForCategory == dropDownFrame.questID then
   i = 10000
  end
  i = i + 1
 end
 info.isNotRadio = true
 info.notCheckable = true
 info.isTitle  = true
   
 -- blank space
 info.text = " "
 UIDropDownMenu_AddButton(info, level)
 -- addon title
 info.text = "|T"..dgcicon..":16|t "..addontitle
 UIDropDownMenu_AddButton(info, level)
 
 -- quest ID
 info.text = AddColor(L["b_questid"].." "..dropDownFrame.questID, GOLD)
 UIDropDownMenu_AddButton(info, level)

 -- add buttons (I really wanted to make a submenu but I couldn't make it work
 info.isTitle  = false
 info.disabled = false
 info.text = L["add"].." ("..string.format(PAGE_NUMBER, 1)..")"
 info.func = function() addtolist(1) end
 UIDropDownMenu_AddButton(info, level)

 info.text = L["add"].." ("..string.format(PAGE_NUMBER, 2)..")" 
 info.func = function() addtolist(2) end
 UIDropDownMenu_AddButton(info, level)

 info.text = L["add"].." ("..string.format(PAGE_NUMBER, 3)..")"
 info.func = function() addtolist(3) end
 UIDropDownMenu_AddButton(info, level)

 addID = dropDownFrame.questID
 addName = questTitle
 
 addCategory = questCategory
 
 --DEFAULT_CHAT_FRAME:AddMessage("Category: " .. questCategory)
end

hooksecurefunc("ToggleDropDownMenu", hookToggleDropDownMenu)

-- slash command
SLASH_DAILYGLOBALCHECK1 = "/dgcheck"
SLASH_DAILYGLOBALCHECK2 = "/dgc"
SlashCmdList["DAILYGLOBALCHECK"] = DGCInit